Semi-Structured Text Formats
============================

Handlers for config-like, markup, and document-style text formats.

.. autosummary::
   :toctree: generated

   etlplus.file.cfg
   etlplus.file.conf
   etlplus.file.ini
   etlplus.file.json
   etlplus.file.ndjson
   etlplus.file.properties
   etlplus.file.toml
   etlplus.file.xml
   etlplus.file.yaml
